@@ -6,6 +6,7 @@ package cli
 import (
 	"errors"
 	"fmt"
+	"github.com/aws/copilot-cli/internal/pkg/aws/iam"
 	"os"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -51,6 +52,7 @@ type initAppOpts struct {
 	cfn                  appDeployer
 	prompt               prompter
 	prog                 progress
+	iam                  policyLister
 	isSessionFromEnvVars func() (bool, error)
 
 	cachedHostedZoneID string
@@ -77,6 +79,7 @@ func newInitAppOpts(vars initAppVars) (*initAppOpts, error) {
 		cfn:              cloudformation.New(sess, cloudformation.WithProgressTracker(os.Stderr)),
 		prompt:           prompt.New(),
 		prog:             termprogress.NewSpinner(log.DiagnosticWriter),
+		iam:              iam.New(sess),
 		isSessionFromEnvVars: func() (bool, error) {
 			return sessions.AreCredsFromEnvVars(sess)
 		},
@@ -90,6 +93,11 @@ func (o *initAppOpts) Validate() error {
 			return err
 		}
 	}
+	if o.permissionsBoundary != "" {
+		if err := o.validatePermBound(o.permissionsBoundary); err != nil {
+			return err
+		}
+	}
 	if o.domainName != "" {
 		if err := validateDomainName(o.domainName); err != nil {
 			return fmt.Errorf("domain name %s is invalid: %w", o.domainName, err)
@@ -234,6 +242,19 @@ func (o *initAppOpts) validateAppName(name string) error {
 	return nil
 }
 
+func (o *initAppOpts) validatePermBound(policyName string) error {
+	IAMPolicies, err := o.iam.ListPolicyNames()
+	if err != nil {
+		return fmt.Errorf("list permissions boundary policies: %w", err)
+	}
+	for _, policy := range IAMPolicies {
+		if policy == policyName {
+			return nil
+		}
+	}
+	return fmt.Errorf("IAM policy %q not found in this account", policyName)
+}
+
 func (o *initAppOpts) isDomainOwned() error {
 	err := o.domainInfoGetter.IsRegisteredDomain(o.domainName)
 	if err == nil {
