@@ -16,7 +16,6 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/aws/sessions"
 	"github.com/aws/copilot-cli/internal/pkg/cli/deploy"
 	"github.com/aws/copilot-cli/internal/pkg/config"
-	"github.com/aws/copilot-cli/internal/pkg/describe"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/aws/copilot-cli/internal/pkg/term/color"
 	"github.com/aws/copilot-cli/internal/pkg/term/log"
@@ -47,7 +46,6 @@ type deployEnvOpts struct {
 	identity        identityService
 	newInterpolator func(app, env string) interpolator
 	newEnvDeployer  func() (envDeployer, error)
-	newEnvDescriber func() (envDescriber, error)
 
 	// Cached variables.
 	targetApp *config.Application
@@ -79,17 +77,6 @@ func newEnvDeployOpts(vars deployEnvVars) (*deployEnvOpts, error) {
 	opts.newEnvDeployer = func() (envDeployer, error) {
 		return newEnvDeployer(opts)
 	}
-	opts.newEnvDescriber = func() (envDescriber, error) {
-		envDescriber, err := describe.NewEnvDescriber(describe.NewEnvDescriberConfig{
-			App:         opts.appName,
-			Env:         opts.name,
-			ConfigStore: opts.store,
-		})
-		if err != nil {
-			return nil, err
-		}
-		return envDescriber, nil
-	}
 	return opts, nil
 }
 
@@ -106,6 +93,7 @@ func newEnvDeployer(opts *deployEnvOpts) (envDeployer, error) {
 		App:             app,
 		Env:             env,
 		SessionProvider: opts.sessionProvider,
+		ConfigStore:     opts.store,
 	})
 }
 
@@ -126,10 +114,6 @@ func (o *deployEnvOpts) Ask() error {
 	return o.validateOrAskEnvName()
 }
 
-func (o *deployEnvOpts) isManagedCDNEnabled(mft *manifest.Environment) bool {
-	return mft.CDNEnabled() && mft.HTTPConfig.Public.Certificates == nil && o.targetApp.Domain != ""
-}
-
 // Execute deploys an environment given a manifest.
 func (o *deployEnvOpts) Execute() error {
 	rawMft, err := o.ws.ReadEnvironmentManifest(o.name)
@@ -140,18 +124,6 @@ func (o *deployEnvOpts) Execute() error {
 	if err != nil {
 		return err
 	}
-	if o.isManagedCDNEnabled(mft) {
-		describer, err := o.newEnvDescriber()
-		if err != nil {
-			return err
-		}
-		// With managed domain, if the customer isn't using `alias` the A-records are inserted in the service stack as each service domain is unique.
-		// However, when clients enable CloudFront, they would need to update all their existing records to now point to the distribution.
-		// Hence, we force users to use `alias` and let the records be written in the environment stack instead.
-		if err := describer.ValidateCFServiceDomainAliases(); err != nil {
-			return err
-		}
-	}
 	caller, err := o.identity.Get()
 	if err != nil {
 		return fmt.Errorf("get identity: %w", err)
@@ -160,6 +132,9 @@ func (o *deployEnvOpts) Execute() error {
 	if err != nil {
 		return err
 	}
+	if err := deployer.Validate(mft); err != nil {
+		return err
+	}
 	urls, err := deployer.UploadArtifacts()
 	if err != nil {
 		return fmt.Errorf("upload artifacts for environment %s: %w", o.name, err)
@@ -170,6 +145,7 @@ func (o *deployEnvOpts) Execute() error {
 		Manifest:            mft,
 		ForceNewUpdate:      o.forceNewUpdate,
 		RawManifest:         rawMft,
+		PermissionsBoundary: o.targetApp.PermissionsBoundary,
 	}); err != nil {
 		var errEmptyChangeSet *awscfn.ErrChangeSetEmpty
 		if errors.As(err, &errEmptyChangeSet) {
