@@ -75,18 +75,12 @@ func newJobLogOpts(vars jobLogsVars) (*jobLogsOpts, error) {
 		if err != nil {
 			return err
 		}
-		opts.logsSvc, err = logging.NewWorkloadClient(&logging.NewWorkloadLogsConfig{
-			Sess:        sess,
-			App:         opts.appName,
-			Env:         opts.envName,
-			Name:        opts.name,
-			LogGroup:    opts.logGroup,
-			TaskIDs:     opts.taskIDs,
-			ConfigStore: configStore,
+		opts.logsSvc = logging.NewJobLogger(&logging.NewWorkloadLoggerOpts{
+			Sess: sess,
+			App:  opts.appName,
+			Env:  opts.envName,
+			Name: opts.name,
 		})
-		if err != nil {
-			return err
-		}
 		return nil
 	}
 	return opts, nil
