@@ -5,7 +5,6 @@ package cli
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -43,7 +42,7 @@ type packageJobOpts struct {
 	// Interfaces to interact with dependencies.
 	ws     wsJobDirReader
 	store  store
-	runner runner
+	runner execRunner
 	sel    wsSelector
 	prompt prompter
 
@@ -84,18 +83,17 @@ func newPackageJobOpts(vars packageJobVars) (*packageJobOpts, error) {
 				outputDir:    o.outputDir,
 				uploadAssets: o.uploadAssets,
 			},
-			runner:           o.runner,
-			initAddonsClient: initPackageAddonsClient,
-			ws:               ws,
-			store:            o.store,
-			stackWriter:      os.Stdout,
-			unmarshal:        manifest.UnmarshalWorkload,
-			newInterpolator:  newManifestInterpolator,
-			paramsWriter:     ioutil.Discard,
-			addonsWriter:     ioutil.Discard,
-			fs:               &afero.Afero{Fs: afero.NewOsFs()},
-			sessProvider:     sessProvider,
-			newTplGenerator:  newWkldTplGenerator,
+			runner:            o.runner,
+			ws:                ws,
+			store:             o.store,
+			templateWriter:    os.Stdout,
+			unmarshal:         manifest.UnmarshalWorkload,
+			newInterpolator:   newManifestInterpolator,
+			paramsWriter:      discardFile{},
+			addonsWriter:      discardFile{},
+			fs:                &afero.Afero{Fs: afero.NewOsFs()},
+			sessProvider:      sessProvider,
+			newStackGenerator: newWorkloadStackGenerator,
 		}
 	}
 	return opts, nil
@@ -140,6 +138,11 @@ func (o *packageJobOpts) Execute() error {
 	return o.packageCmd.Execute()
 }
 
+// RecommendActions suggests recommended actions before the packaged template is used for deployment.
+func (o *packageJobOpts) RecommendActions() error {
+	return o.packageCmd.RecommendActions()
+}
+
 func (o *packageJobOpts) askJobName() error {
 	if o.name != "" {
 		return nil
@@ -171,16 +174,18 @@ func buildJobPackageCmd() *cobra.Command {
 	vars := packageJobVars{}
 	cmd := &cobra.Command{
 		Use:   "package",
-		Short: "Prints the AWS CloudFormation template of a job.",
-		Long:  `Prints the CloudFormation template used to deploy a job to an environment.`,
+		Short: "Print the AWS CloudFormation template of a job.",
+		Long:  `Print the CloudFormation template used to deploy a job to an environment.`,
 		Example: `
   Print the CloudFormation template for the "report-generator" job parametrized for the "test" environment.
   /code $ copilot job package -n report-generator -e test
 
   Write the CloudFormation stack and configuration to a "infrastructure/" sub-directory instead of printing.
-  /code $ copilot job package -n report-generator -e test --output-dir ./infrastructure
-  /code $ ls ./infrastructure
-  /code report-generator-test.stack.yml      report-generator-test.params.yml`,
+  /startcodeblock
+  $ copilot job package -n report-generator -e test --output-dir ./infrastructure
+  $ ls ./infrastructure
+  report-generator-test.stack.yml      report-generator-test.params.yml
+  /endcodeblock`,
 		RunE: runCmdE(func(cmd *cobra.Command, args []string) error {
 			opts, err := newPackageJobOpts(vars)
 			if err != nil {
