@@ -7,10 +7,11 @@ import (
 	"bytes"
 	"errors"
 	"fmt"
-	"github.com/aws/aws-sdk-go/aws"
 	"path/filepath"
 	"testing"
 
+	"github.com/aws/aws-sdk-go/aws"
+
 	"github.com/aws/aws-sdk-go/aws/session"
 
 	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
@@ -157,7 +158,7 @@ func TestTaskRunOpts_Validate(t *testing.T) {
 			basicOpts:   defaultOpts,
 			inOS:        "OStrich",
 			inArch:      "MAD666",
-			wantedError: errors.New("platform OSTRICH/MAD666 is invalid; valid platforms are: WINDOWS_SERVER_2019_CORE/X86_64, WINDOWS_SERVER_2019_FULL/X86_64, LINUX/X86_64 and LINUX/ARM64"),
+			wantedError: errors.New("platform OSTRICH/MAD666 is invalid; valid platforms are: WINDOWS_SERVER_2019_CORE/X86_64, WINDOWS_SERVER_2019_FULL/X86_64, WINDOWS_SERVER_2022_CORE/X86_64, WINDOWS_SERVER_2022_FULL/X86_64, LINUX/X86_64 and LINUX/ARM64"),
 		},
 		"uppercase any lowercase before validating": {
 			basicOpts: basicOpts{
@@ -1007,6 +1008,23 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 			},
 			wantedError: errors.New("write events: error writing events"),
 		},
+		"error getting app config (to look for permissions boundary policy)": {
+			inApp: "my-app",
+			inEnv: "test",
+			setupMocks: func(m runTaskMocks) {
+				m.store.EXPECT().GetEnvironment(gomock.Any(), "test").
+					Return(&config.Environment{
+						ExecutionRoleARN: "env execution role",
+					}, nil)
+				m.provider.EXPECT().FromRole(gomock.Any(), gomock.Any())
+				m.store.EXPECT().GetApplication("my-app").Return(nil, errors.New("some error"))
+				m.deployer.EXPECT().DeployTask(gomock.Any(), gomock.Len(1)).AnyTimes() // NOTE: matching length because gomock is unable to match function arguments.
+				mockRepositoryAnytime(m)
+				m.runner.EXPECT().Run().AnyTimes()
+				m.defaultClusterGetter.EXPECT().HasDefaultCluster().Times(0)
+			},
+			wantedError: fmt.Errorf("provision resources for task %s: get application: some error", "my-task"),
+		},
 		"env file happy path": {
 			inEnvFile: "testdir/../magic.env",
 			inApp:     "my-app",
@@ -1026,6 +1044,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 				}, nil)
 				m.defaultClusterGetter.EXPECT().HasDefaultCluster().Return(true, nil)
 				info := deploy.TaskStackInfo{BucketName: "arn:aws:s3:::bigbucket"}
+				m.store.EXPECT().GetApplication("my-app").Return(&config.Application{Name: "my-app"}, nil).Times(2)
 				m.deployer.EXPECT().GetTaskStack(inGroupName).Return(&info, nil)
 				key := "manual/env-files/magic.env/4963d64294508aa3fa103ccac5ad1537944c577d469608ddccad09b6f79b6406.env"
 				arn := "arn:aws:s3:::bigbucket/" + key
@@ -1050,6 +1069,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 				}, nil)
 				m.defaultClusterGetter.EXPECT().HasDefaultCluster().Return(true, nil)
 				info := deploy.TaskStackInfo{BucketName: "arn:aws:s3:::bigbucket"}
+				m.store.EXPECT().GetApplication("my-app").Return(&config.Application{Name: "my-app"}, nil)
 				m.deployer.EXPECT().GetTaskStack(inGroupName).Return(&info, nil)
 				m.deployer.EXPECT().DeployTask(gomock.Any(), gomock.Any()).Return(nil)
 			},
@@ -1073,6 +1093,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 					},
 				}, nil)
 				m.defaultClusterGetter.EXPECT().HasDefaultCluster().Return(true, nil)
+				m.store.EXPECT().GetApplication("my-app").Return(&config.Application{Name: "my-app"}, nil)
 				m.deployer.EXPECT().GetTaskStack(inGroupName).Return(nil, errors.New("hull breach in sector 3"))
 			},
 			wantedError: errors.New("deploy env file testdir/../magic.env: deploy env file: hull breach in sector 3"),
@@ -1096,6 +1117,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 				}, nil)
 				m.defaultClusterGetter.EXPECT().HasDefaultCluster().Return(true, nil)
 				info := deploy.TaskStackInfo{BucketName: "arn:aws:s3:::bigbucket"}
+				m.store.EXPECT().GetApplication("my-app").Return(&config.Application{Name: "my-app"}, nil)
 				m.deployer.EXPECT().GetTaskStack(inGroupName).Return(&info, nil)
 
 				key := "manual/env-files/magic.env/4963d64294508aa3fa103ccac5ad1537944c577d469608ddccad09b6f79b6406.env"
@@ -1172,7 +1194,7 @@ func TestTaskRunOpts_Execute(t *testing.T) {
 
 			err := opts.Execute()
 			if tc.wantedError != nil {
-				require.EqualError(t, tc.wantedError, err.Error())
+				require.EqualError(t, err, tc.wantedError.Error())
 			} else {
 				require.NoError(t, err)
 			}
@@ -1187,8 +1209,9 @@ type mockRunTaskRequester struct {
 }
 
 type taskRunMocks struct {
-	store    *mocks.Mockstore
-	provider *mocks.MocksessionProvider
+	store                   *mocks.Mockstore
+	provider                *mocks.MocksessionProvider
+	envCompatibilityChecker *mocks.MockversionCompatibilityChecker
 }
 
 func TestTaskRunOpts_runTaskCommand(t *testing.T) {
@@ -1215,7 +1238,7 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 			},
 			wantedCommand: &wantedCommand,
 		},
-		"fail to generate a command given an service ARN": {
+		"fail to generate a command given a service ARN": {
 			inGenerateCommandTarget: "arn:aws:ecs:us-east-1:123456789012:service/crowded-cluster/good-service",
 			setUpMocks: func(m *taskRunMocks) {
 				m.provider.EXPECT().Default()
@@ -1296,6 +1319,7 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 				}, nil)
 				m.provider.EXPECT().FromRole("mock-role", "mock-region")
 				m.store.EXPECT().GetJob("good-app", "good-job").Return(&config.Workload{}, nil)
+				m.envCompatibilityChecker.EXPECT().Version().Return("v1.12.2", nil)
 			},
 			mockRunTaskRequester: mockRunTaskRequester{
 				mockRunTaskRequestFromJob: func(client ecs.JobDescriber, app, env, svc string) (*ecs.RunTaskRequest, error) {
@@ -1313,6 +1337,7 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 				}, nil)
 				m.provider.EXPECT().FromRole("mock-role", "mock-region")
 				m.store.EXPECT().GetJob("good-app", "good-job").Return(&config.Workload{}, nil)
+				m.envCompatibilityChecker.EXPECT().Version().Return("v1.12.2", nil)
 			},
 			mockRunTaskRequester: mockRunTaskRequester{
 				mockRunTaskRequestFromJob: func(client ecs.JobDescriber, app, env, svc string) (*ecs.RunTaskRequest, error) {
@@ -1321,6 +1346,34 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 			},
 			wantedError: fmt.Errorf("generate task run command from job good-job of application good-app deployed in environment good-env: some error"),
 		},
+		"error out if fail to get env version when target is job": {
+			inGenerateCommandTarget: "good-app/good-env/good-job",
+			setUpMocks: func(m *taskRunMocks) {
+				m.store.EXPECT().GetEnvironment("good-app", "good-env").Return(&config.Environment{
+					ManagerRoleARN: "mock-role",
+					Region:         "mock-region",
+				}, nil)
+				m.provider.EXPECT().FromRole("mock-role", "mock-region")
+				m.store.EXPECT().GetJob("good-app", "good-job").Return(&config.Workload{}, nil)
+				m.envCompatibilityChecker.EXPECT().Version().Return("", errors.New("some error"))
+			},
+
+			wantedError: fmt.Errorf(`retrieve version of environment stack "good-env" in application "good-app": some error`),
+		},
+		"error out if env version doesn't support `--generate-cmd` for jobs": {
+			inGenerateCommandTarget: "good-app/good-env/good-job",
+			setUpMocks: func(m *taskRunMocks) {
+				m.store.EXPECT().GetEnvironment("good-app", "good-env").Return(&config.Environment{
+					ManagerRoleARN: "mock-role",
+					Region:         "mock-region",
+				}, nil)
+				m.provider.EXPECT().FromRole("mock-role", "mock-region")
+				m.store.EXPECT().GetJob("good-app", "good-job").Return(&config.Workload{}, nil)
+				m.envCompatibilityChecker.EXPECT().Version().Return("v1.9.0", nil)
+			},
+
+			wantedError: fmt.Errorf(`environment "good-env" is on version "v1.9.0" which does not support the "task run --generate-cmd" feature`),
+		},
 		"fail to determine if the workload is a job given an app/env/workload target": {
 			inGenerateCommandTarget: "good-app/good-env/bad-workload",
 			setUpMocks: func(m *taskRunMocks) {
@@ -1371,8 +1424,9 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 			defer ctrl.Finish()
 
 			m := &taskRunMocks{
-				store:    mocks.NewMockstore(ctrl),
-				provider: mocks.NewMocksessionProvider(ctrl),
+				store:                   mocks.NewMockstore(ctrl),
+				provider:                mocks.NewMocksessionProvider(ctrl),
+				envCompatibilityChecker: mocks.NewMockversionCompatibilityChecker(ctrl),
 			}
 			if tc.setUpMocks != nil {
 				tc.setUpMocks(m)
@@ -1393,15 +1447,17 @@ func TestTaskRunOpts_runTaskCommand(t *testing.T) {
 				configureServiceDescriber: func(session *session.Session) ecs.ServiceDescriber {
 					return ecsMocks.NewMockServiceDescriber(ctrl)
 				},
-
 				runTaskRequestFromECSService: tc.mockRunTaskRequester.mockRunTaskRequestFromECSService,
 				runTaskRequestFromService:    tc.mockRunTaskRequester.mockRunTaskRequestFromService,
 				runTaskRequestFromJob:        tc.mockRunTaskRequester.mockRunTaskRequestFromJob,
+				envCompatibilityChecker: func(app, env string) (versionCompatibilityChecker, error) {
+					return m.envCompatibilityChecker, nil
+				},
 			}
 
 			got, err := opts.runTaskCommand()
 			if tc.wantedError != nil {
-				require.EqualError(t, tc.wantedError, err.Error())
+				require.EqualError(t, err, tc.wantedError.Error())
 			} else {
 				require.NoError(t, err)
 				require.Equal(t, tc.wantedCommand, got)
