@@ -93,7 +93,9 @@ func TestScheduledJob_Validate(t *testing.T) {
 	require.ErrorAs(t, err, &notFound)
 
 	serializer, err := stack.NewScheduledJob(stack.ScheduledJobConfig{
-		App:      appName,
+		App: &config.Application{
+			Name: appName,
+		},
 		Env:      envName,
 		Manifest: v,
 		RuntimeConfig: stack.RuntimeConfig{
@@ -101,6 +103,8 @@ func TestScheduledJob_Validate(t *testing.T) {
 			CustomResourcesURL: map[string]string{
 				"EnvControllerFunction": "https://my-bucket.s3.us-west-2.amazonaws.com/code.zip",
 			},
+			AccountID:  "123456789123",
+			Region:     "us-west-2",
 			EnvVersion: "v1.42.0",
 		},
 	})
