@@ -63,14 +63,13 @@ type CustomResource struct {
 	zip *bytes.Buffer
 }
 
-// FunctionName is the name of the Lambda function.
-func (cr *CustomResource) FunctionName() string {
+// Name returns the name of the custom resource.
+func (cr *CustomResource) Name() string {
 	return cr.name
 }
 
-// ArtifactPath returns the S3 key for the zipped custom resource object.
-func (cr *CustomResource) ArtifactPath() string {
-	return artifactpath.CustomResource(strings.ToLower(cr.FunctionName()), cr.zip.Bytes())
+func (cr *CustomResource) artifactPath() string {
+	return artifactpath.CustomResource(strings.ToLower(cr.Name()), cr.zip.Bytes())
 }
 
 // zipReader returns a reader for the zip archive from all the files in the custom resource.
@@ -84,15 +83,15 @@ func (cr *CustomResource) init() error {
 	for _, file := range cr.files {
 		f, err := w.Create(file.name)
 		if err != nil {
-			return fmt.Errorf("create zip file %q for custom resource %q: %v", file.name, cr.FunctionName(), err)
+			return fmt.Errorf("create zip file %q for custom resource %q: %v", file.name, cr.Name(), err)
 		}
 		_, err = f.Write(file.content)
 		if err != nil {
-			return fmt.Errorf("write zip file %q for custom resource %q: %v", file.name, cr.FunctionName(), err)
+			return fmt.Errorf("write zip file %q for custom resource %q: %v", file.name, cr.Name(), err)
 		}
 	}
 	if err := w.Close(); err != nil {
-		return fmt.Errorf("close zip file for custom resource %q: %v", cr.FunctionName(), err)
+		return fmt.Errorf("close zip file for custom resource %q: %v", cr.Name(), err)
 	}
 	cr.zip = buf
 	return nil
@@ -166,11 +165,11 @@ type UploadFunc func(key string, contents io.Reader) (url string, err error)
 func Upload(upload UploadFunc, crs []*CustomResource) (map[string]string, error) {
 	urls := make(map[string]string)
 	for _, cr := range crs {
-		url, err := upload(cr.ArtifactPath(), cr.zipReader())
+		url, err := upload(cr.artifactPath(), cr.zipReader())
 		if err != nil {
-			return nil, fmt.Errorf("upload custom resource %q: %w", cr.FunctionName(), err)
+			return nil, fmt.Errorf("upload custom resource %q: %w", cr.Name(), err)
 		}
-		urls[cr.FunctionName()] = url
+		urls[cr.Name()] = url
 	}
 	return urls, nil
 }
