@@ -12,6 +12,7 @@ import (
 	"github.com/dustin/go-humanize"
 
 	"github.com/aws/copilot-cli/internal/pkg/aws/codepipeline"
+	"github.com/aws/copilot-cli/internal/pkg/deploy"
 	"github.com/aws/copilot-cli/internal/pkg/describe/mocks"
 	"github.com/golang/mock/gomock"
 	"github.com/stretchr/testify/require"
@@ -21,13 +22,12 @@ type pipelineStatusDescriberMocks struct {
 	pipelineStateGetter *mocks.MockpipelineStateGetter
 }
 
-var mockPipelineName = "pipeline-dinder-badgoose-repo"
 var mockParsedTime = func() time.Time {
 	t, _ := time.Parse(time.RFC3339, "2020-02-02T15:04:05+00:00")
 	return t
 }
 var mockPipelineState = &codepipeline.PipelineState{
-	PipelineName: mockPipelineName,
+	PipelineName: pipelineResourceName,
 	StageStates: []*codepipeline.StageState{
 		{
 			StageName: "Source",
@@ -88,17 +88,20 @@ func TestPipelineStatusDescriber_Describe(t *testing.T) {
 	}{
 		"wraps GetPipelineState error": {
 			setupMocks: func(m pipelineStatusDescriberMocks) {
-				m.pipelineStateGetter.EXPECT().GetPipelineState(pipelineName).Return(nil, mockError)
+				m.pipelineStateGetter.EXPECT().GetPipelineState(pipelineResourceName).Return(nil, mockError)
 			},
 			expectedError:  fmt.Errorf("get pipeline status: %w", mockError),
 			expectedOutput: nil,
 		},
 		"success": {
 			setupMocks: func(m pipelineStatusDescriberMocks) {
-				m.pipelineStateGetter.EXPECT().GetPipelineState(pipelineName).Return(mockPipelineState, nil)
+				m.pipelineStateGetter.EXPECT().GetPipelineState(pipelineResourceName).Return(mockPipelineState, nil)
+			},
+			expectedError: nil,
+			expectedOutput: &PipelineStatus{
+				Name:          pipelineName,
+				PipelineState: *mockPipelineState,
 			},
-			expectedError:  nil,
-			expectedOutput: &PipelineStatus{*mockPipelineState},
 		},
 	}
 	for name, tc := range testCases {
@@ -113,9 +116,16 @@ func TestPipelineStatusDescriber_Describe(t *testing.T) {
 			}
 			tc.setupMocks(mocks)
 
+			mockDeployedPipeline := deploy.Pipeline{
+				Name:         pipelineName,
+				ResourceName: pipelineResourceName,
+				AppName:      "mockApp",
+				IsLegacy:     false,
+			}
+
 			describer := &PipelineStatusDescriber{
-				pipelineName: pipelineName,
-				pipelineSvc:  mockPipelineStateGetter,
+				pipeline:    mockDeployedPipeline,
+				pipelineSvc: mockPipelineStateGetter,
 			}
 
 			// WHEN
@@ -147,7 +157,9 @@ func TestPipelineStatusDescriber_String(t *testing.T) {
 		expectedJSONString  string
 	}{
 		"correct output with correct aggregate statuses": {
-			testPipelineStatus: &PipelineStatus{*mockPipelineState},
+			testPipelineStatus: &PipelineStatus{
+				Name:          pipelineName,
+				PipelineState: *mockPipelineState},
 			expectedHumanString: `Pipeline Status
 
 Stage             Transition  Status
@@ -167,7 +179,7 @@ Last Deployment
 
   Updated At  4 months ago
 `,
-			expectedJSONString: "{\"pipelineName\":\"pipeline-dinder-badgoose-repo\",\"stageStates\":[{\"stageName\":\"Source\",\"transition\":\"\"},{\"stageName\":\"Build\",\"actions\":[{\"name\":\"action1\",\"status\":\"Failed\"},{\"name\":\"action2\",\"status\":\"InProgress\"},{\"name\":\"action3\",\"status\":\"Succeeded\"}],\"transition\":\"ENABLED\"},{\"stageName\":\"DeployTo-test\",\"actions\":[{\"name\":\"action1\",\"status\":\"Succeeded\"}],\"transition\":\"DISABLED\"},{\"stageName\":\"DeployTo-prod\",\"actions\":[{\"name\":\"action1\",\"status\":\"Succeeded\"},{\"name\":\"TestCommands\",\"status\":\"Failed\"}],\"transition\":\"\"}],\"updatedAt\":\"2020-02-02T15:04:05Z\"}\n",
+			expectedJSONString: "{\"name\":\"pipeline-dinder-badgoose-repo\",\"pipelineName\":\"pipeline-dinder-badgoose-repo-RANDOMSTRING\",\"stageStates\":[{\"stageName\":\"Source\",\"transition\":\"\"},{\"stageName\":\"Build\",\"actions\":[{\"name\":\"action1\",\"status\":\"Failed\"},{\"name\":\"action2\",\"status\":\"InProgress\"},{\"name\":\"action3\",\"status\":\"Succeeded\"}],\"transition\":\"ENABLED\"},{\"stageName\":\"DeployTo-test\",\"actions\":[{\"name\":\"action1\",\"status\":\"Succeeded\"}],\"transition\":\"DISABLED\"},{\"stageName\":\"DeployTo-prod\",\"actions\":[{\"name\":\"action1\",\"status\":\"Succeeded\"},{\"name\":\"TestCommands\",\"status\":\"Failed\"}],\"transition\":\"\"}],\"updatedAt\":\"2020-02-02T15:04:05Z\"}\n",
 		},
 	}
 	for _, tc := range testCases {
