@@ -94,7 +94,7 @@ type EnvironmentConfig struct {
 	Network       environmentNetworkConfig `yaml:"network,omitempty,flow"`
 	Observability environmentObservability `yaml:"observability,omitempty,flow"`
 	HTTPConfig    EnvironmentHTTPConfig    `yaml:"http,omitempty,flow"`
-	CDNConfig     environmentCDNConfig     `yaml:"cdn,omitempty,flow"`
+	CDNConfig     EnvironmentCDNConfig     `yaml:"cdn,omitempty,flow"`
 }
 
 // IsIngressRestrictedToCDN returns whether or not an environment has its
@@ -184,24 +184,26 @@ func (cfg *EnvironmentConfig) EnvSecurityGroup() (*securityGroupConfig, bool) {
 	return nil, false
 }
 
-type environmentCDNConfig struct {
+// EnvironmentCDNConfig represents configuration of a CDN.
+type EnvironmentCDNConfig struct {
 	Enabled *bool
-	Config  advancedCDNConfig // mutually exclusive with Enabled
+	Config  AdvancedCDNConfig // mutually exclusive with Enabled
 }
 
-// advancedCDNConfig represents an advanced configuration for a Content Delivery Network.
-type advancedCDNConfig struct {
-	Certificate *string `yaml:"certificate"`
+// AdvancedCDNConfig represents an advanced configuration for a Content Delivery Network.
+type AdvancedCDNConfig struct {
+	Certificate  *string `yaml:"certificate,omitempty"`
+	TerminateTLS *bool   `yaml:"terminate_tls,omitempty"`
 }
 
 // IsEmpty returns whether environmentCDNConfig is empty.
-func (cfg *environmentCDNConfig) IsEmpty() bool {
+func (cfg *EnvironmentCDNConfig) IsEmpty() bool {
 	return cfg.Enabled == nil && cfg.Config.isEmpty()
 }
 
 // isEmpty returns whether advancedCDNConfig is empty.
-func (cfg *advancedCDNConfig) isEmpty() bool {
-	return cfg.Certificate == nil
+func (cfg *AdvancedCDNConfig) isEmpty() bool {
+	return cfg.Certificate == nil && cfg.TerminateTLS == nil
 }
 
 // CDNEnabled returns whether a CDN configuration has been enabled in the environment manifest.
@@ -212,10 +214,22 @@ func (cfg *EnvironmentConfig) CDNEnabled() bool {
 	return aws.BoolValue(cfg.CDNConfig.Enabled)
 }
 
+// HasImportedPublicALBCerts returns true when the environment's ALB
+// is configured with certs for the public listener.
+func (cfg *EnvironmentConfig) HasImportedPublicALBCerts() bool {
+	return cfg.HTTPConfig.Public.Certificates != nil
+}
+
+// CDNDoesTLSTermination returns true when the environment's CDN
+// is configured to terminate incoming TLS connections.
+func (cfg *EnvironmentConfig) CDNDoesTLSTermination() bool {
+	return aws.BoolValue(cfg.CDNConfig.Config.TerminateTLS)
+}
+
 // UnmarshalYAML overrides the default YAML unmarshaling logic for the environmentCDNConfig
 // struct, allowing it to perform more complex unmarshaling behavior.
 // This method implements the yaml.Unmarshaler (v3) interface.
-func (cfg *environmentCDNConfig) UnmarshalYAML(value *yaml.Node) error {
+func (cfg *EnvironmentCDNConfig) UnmarshalYAML(value *yaml.Node) error {
 	if err := value.Decode(&cfg.Config); err != nil {
 		var yamlTypeErr *yaml.TypeError
 		if !errors.As(err, &yamlTypeErr) {
@@ -495,6 +509,12 @@ type Ingress struct {
 	VPCIngress         *bool              `yaml:"from_vpc"`
 }
 
+// ALBIngressRestrictedToCDN returns true when the environment is configured
+// to only allow ALB ingress from the CDN.
+func (cfg *EnvironmentConfig) ALBIngressRestrictedToCDN() bool {
+	return aws.BoolValue(cfg.HTTPConfig.Public.SecurityGroupConfig.Ingress.RestrictiveIngress.CDNIngress)
+}
+
 // RestrictiveIngress represents ingress fields which restrict
 // default behavior of allowing all public ingress.
 type RestrictiveIngress struct {
