@@ -565,6 +565,21 @@ func TestBackendService_validate(t *testing.T) {
 			},
 			wantedError: errors.New(`"http" must be specified if "count.requests" or "count.response_time" are specified`),
 		},
+		"error if invalid topic is defined": {
+			config: BackendService{
+				BackendServiceConfig: BackendServiceConfig{
+					ImageConfig: testImageConfig,
+					PublishConfig: PublishConfig{
+						Topics: []Topic{
+							{
+								Name: aws.String("mytopic.fifo"),
+							},
+						},
+					},
+				},
+			},
+			wantedErrorMsgPrefix: `validate "publish": `,
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -1617,7 +1632,7 @@ func TestPlatformArgsOrString_validate(t *testing.T) {
 					Arch:     aws.String("amd64"),
 				},
 			},
-			wanted: fmt.Errorf("platform pair ('foo', 'amd64') is invalid: fields ('osfamily', 'architecture') must be one of ('linux', 'x86_64'), ('linux', 'amd64'), ('linux', 'arm'), ('linux', 'arm64'), ('windows', 'x86_64'), ('windows', 'amd64'), ('windows_server_2019_core', 'x86_64'), ('windows_server_2019_core', 'amd64'), ('windows_server_2019_full', 'x86_64'), ('windows_server_2019_full', 'amd64')"),
+			wanted: fmt.Errorf("platform pair ('foo', 'amd64') is invalid: fields ('osfamily', 'architecture') must be one of ('linux', 'x86_64'), ('linux', 'amd64'), ('linux', 'arm'), ('linux', 'arm64'), ('windows', 'x86_64'), ('windows', 'amd64'), ('windows_server_2019_core', 'x86_64'), ('windows_server_2019_core', 'amd64'), ('windows_server_2019_full', 'x86_64'), ('windows_server_2019_full', 'amd64'), ('windows_server_2022_core', 'x86_64'), ('windows_server_2022_core', 'amd64'), ('windows_server_2022_full', 'x86_64'), ('windows_server_2022_full', 'amd64')"),
 		},
 		"error if arch is invalid": {
 			in: PlatformArgsOrString{
@@ -1626,7 +1641,7 @@ func TestPlatformArgsOrString_validate(t *testing.T) {
 					Arch:     aws.String("bar"),
 				},
 			},
-			wanted: fmt.Errorf("platform pair ('linux', 'bar') is invalid: fields ('osfamily', 'architecture') must be one of ('linux', 'x86_64'), ('linux', 'amd64'), ('linux', 'arm'), ('linux', 'arm64'), ('windows', 'x86_64'), ('windows', 'amd64'), ('windows_server_2019_core', 'x86_64'), ('windows_server_2019_core', 'amd64'), ('windows_server_2019_full', 'x86_64'), ('windows_server_2019_full', 'amd64')"),
+			wanted: fmt.Errorf("platform pair ('linux', 'bar') is invalid: fields ('osfamily', 'architecture') must be one of ('linux', 'x86_64'), ('linux', 'amd64'), ('linux', 'arm'), ('linux', 'arm64'), ('windows', 'x86_64'), ('windows', 'amd64'), ('windows_server_2019_core', 'x86_64'), ('windows_server_2019_core', 'amd64'), ('windows_server_2019_full', 'x86_64'), ('windows_server_2019_full', 'amd64'), ('windows_server_2022_core', 'x86_64'), ('windows_server_2022_core', 'amd64'), ('windows_server_2022_full', 'x86_64'), ('windows_server_2022_full', 'amd64')"),
 		},
 		"return nil if platform string valid": {
 			in: PlatformArgsOrString{PlatformString: (*PlatformString)(aws.String("linux/amd64"))},
@@ -2541,7 +2556,7 @@ func TestAppRunnerInstanceConfig_validate(t *testing.T) {
 					},
 				},
 			},
-			wantedError: fmt.Errorf("validate \"platform\": platform pair ('linux', 'leg64') is invalid: fields ('osfamily', 'architecture') must be one of ('linux', 'x86_64'), ('linux', 'amd64'), ('linux', 'arm'), ('linux', 'arm64'), ('windows', 'x86_64'), ('windows', 'amd64'), ('windows_server_2019_core', 'x86_64'), ('windows_server_2019_core', 'amd64'), ('windows_server_2019_full', 'x86_64'), ('windows_server_2019_full', 'amd64')"),
+			wantedError: fmt.Errorf("validate \"platform\": platform pair ('linux', 'leg64') is invalid: fields ('osfamily', 'architecture') must be one of ('linux', 'x86_64'), ('linux', 'amd64'), ('linux', 'arm'), ('linux', 'arm64'), ('windows', 'x86_64'), ('windows', 'amd64'), ('windows_server_2019_core', 'x86_64'), ('windows_server_2019_core', 'amd64'), ('windows_server_2019_full', 'x86_64'), ('windows_server_2019_full', 'amd64'), ('windows_server_2022_core', 'x86_64'), ('windows_server_2022_core', 'amd64'), ('windows_server_2022_full', 'x86_64'), ('windows_server_2022_full', 'amd64')"),
 		},
 		"error if App Runner + ARM": {
 			config: AppRunnerInstanceConfig{
@@ -2638,6 +2653,26 @@ func TestPublishConfig_validate(t *testing.T) {
 			},
 			wantedErrorPrefix: `validate "topics[0]": `,
 		},
+		"error if empty topic name": {
+			config: PublishConfig{
+				Topics: []Topic{
+					{
+						Name: aws.String(""),
+					},
+				},
+			},
+			wantedErrorPrefix: `validate "topics[0]": `,
+		},
+		"error if invalid topic name": {
+			config: PublishConfig{
+				Topics: []Topic{
+					{
+						Name: aws.String("mytopic.lifo"),
+					},
+				},
+			},
+			wantedErrorPrefix: `validate "topics[0]": `,
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
@@ -2665,7 +2700,33 @@ func TestTopic_validate(t *testing.T) {
 			in: Topic{
 				Name: aws.String("!@#"),
 			},
-			wanted: errors.New(`"name" can only contain letters, numbers, underscores, and hypthens`),
+			wanted: errors.New(`"name" can only contain letters, numbers, underscores, and hyphens`),
+		},
+		"should not return an error if name is valid": {
+			in: Topic{
+				Name: aws.String("validtopic"),
+			},
+			wanted: nil,
+		},
+		"should not return an error if name is valid with fifo enabled": {
+			in: Topic{
+				Name: aws.String("validtopic"),
+				FIFO: FIFOTopicAdvanceConfigOrBool{
+					Enable: aws.Bool(true),
+				},
+			},
+			wanted: nil,
+		},
+		"should not return an error if name is valid with advanced fifo config": {
+			in: Topic{
+				Name: aws.String("validtopic"),
+				FIFO: FIFOTopicAdvanceConfigOrBool{
+					Advanced: FIFOTopicAdvanceConfig{
+						ContentBasedDeduplication: aws.Bool(true),
+					},
+				},
+			},
+			wanted: nil,
 		},
 	}
 	for name, tc := range testCases {
@@ -2712,6 +2773,7 @@ func TestSubscribeConfig_validate(t *testing.T) {
 }
 
 func TestTopicSubscription_validate(t *testing.T) {
+	duration111Seconds := 111 * time.Second
 	testCases := map[string]struct {
 		in     TopicSubscription
 		wanted error
@@ -2733,6 +2795,195 @@ func TestTopicSubscription_validate(t *testing.T) {
 			},
 			wanted: errors.New("service name must start with a letter, contain only lower-case letters, numbers, and hyphens, and have no consecutive or trailing hyphen"),
 		},
+		"should not return an error if service is in valid format": {
+			in: TopicSubscription{
+				Name:    aws.String("mockTopic"),
+				Service: aws.String("mockservice"),
+			},
+			wanted: nil,
+		},
+		"should not return error if standard queue is enabled": {
+			in: TopicSubscription{
+				Name:    aws.String("mockTopic"),
+				Service: aws.String("mockservice"),
+				Queue: SQSQueueOrBool{
+					Enabled: aws.Bool(true),
+				},
+			},
+			wanted: nil,
+		},
+		"should not return error if fifo queue is enabled": {
+			in: TopicSubscription{
+				Name:    aws.String("mockTopic"),
+				Service: aws.String("mockservice"),
+				Queue: SQSQueueOrBool{
+					Advanced: SQSQueue{
+						FIFO: FIFOAdvanceConfigOrBool{
+							Enable: aws.Bool(true),
+						},
+					},
+				},
+			},
+			wanted: nil,
+		},
+		"should return error if invalid fifo throughput limit": {
+			in: TopicSubscription{
+				Name:    aws.String("mockTopic"),
+				Service: aws.String("mockservice"),
+				Queue: SQSQueueOrBool{
+					Advanced: SQSQueue{
+						Retention:  &duration111Seconds,
+						Delay:      &duration111Seconds,
+						Timeout:    &duration111Seconds,
+						DeadLetter: DeadLetterQueue{Tries: aws.Uint16(10)},
+						FIFO: FIFOAdvanceConfigOrBool{
+							Advanced: FIFOAdvanceConfig{
+								FIFOThroughputLimit: aws.String("incorrectFIFOThoughoutLimit"),
+							},
+						},
+					},
+				},
+			},
+			wanted: errors.New(`validate "queue": validate "throughput_limit": fifo throughput limit value must be one of perMessageGroupId or perQueue`),
+		},
+		"should not return error if valid fifo throughput limit": {
+			in: TopicSubscription{
+				Name:    aws.String("mockTopic"),
+				Service: aws.String("mockservice"),
+				Queue: SQSQueueOrBool{
+					Advanced: SQSQueue{
+						Retention:  &duration111Seconds,
+						Delay:      &duration111Seconds,
+						Timeout:    &duration111Seconds,
+						DeadLetter: DeadLetterQueue{Tries: aws.Uint16(10)},
+						FIFO: FIFOAdvanceConfigOrBool{
+							Advanced: FIFOAdvanceConfig{
+								FIFOThroughputLimit: aws.String(sqsFIFOThroughputLimitPerMessageGroupID),
+							},
+						},
+					},
+				},
+			},
+			wanted: nil,
+		},
+		"should return error if invalid deduplicate scope": {
+			in: TopicSubscription{
+				Name:    aws.String("mockTopic"),
+				Service: aws.String("mockservice"),
+				Queue: SQSQueueOrBool{
+					Advanced: SQSQueue{
+						Retention:  &duration111Seconds,
+						Delay:      &duration111Seconds,
+						Timeout:    &duration111Seconds,
+						DeadLetter: DeadLetterQueue{Tries: aws.Uint16(10)},
+						FIFO: FIFOAdvanceConfigOrBool{
+							Advanced: FIFOAdvanceConfig{
+								DeduplicationScope: aws.String("incorrectDeduplicateScope"),
+							},
+						},
+					},
+				},
+			},
+			wanted: errors.New(`validate "queue": validate "deduplication_scope": deduplication scope value must be one of messageGroup or queue`),
+		},
+		"should not return error if valid deduplicate scope": {
+			in: TopicSubscription{
+				Name:    aws.String("mockTopic"),
+				Service: aws.String("mockservice"),
+				Queue: SQSQueueOrBool{
+					Advanced: SQSQueue{
+						Retention:  &duration111Seconds,
+						Delay:      &duration111Seconds,
+						Timeout:    &duration111Seconds,
+						DeadLetter: DeadLetterQueue{Tries: aws.Uint16(10)},
+						FIFO: FIFOAdvanceConfigOrBool{
+							Advanced: FIFOAdvanceConfig{
+								DeduplicationScope: aws.String(sqsDeduplicationScopeMessageGroup),
+							},
+						},
+					},
+				},
+			},
+			wanted: nil,
+		},
+		"should return error if high_throughput is defined along with deduplication_scope": {
+			in: TopicSubscription{
+				Name:    aws.String("mockTopic"),
+				Service: aws.String("mockservice"),
+				Queue: SQSQueueOrBool{
+					Advanced: SQSQueue{
+						Retention:  &duration111Seconds,
+						Delay:      &duration111Seconds,
+						Timeout:    &duration111Seconds,
+						DeadLetter: DeadLetterQueue{Tries: aws.Uint16(10)},
+						FIFO: FIFOAdvanceConfigOrBool{
+							Advanced: FIFOAdvanceConfig{
+								HighThroughputFifo: aws.Bool(true),
+								DeduplicationScope: aws.String(sqsDeduplicationScopeMessageGroup),
+							},
+						},
+					},
+				},
+			},
+			wanted: errors.New(`validate "queue": must specify one, not both, of "high_throughput" and "deduplication_scope"`),
+		},
+		"should return error if high_throughput is defined along with  throughput_limit": {
+			in: TopicSubscription{
+				Name:    aws.String("mockTopic"),
+				Service: aws.String("mockservice"),
+				Queue: SQSQueueOrBool{
+					Advanced: SQSQueue{
+						Retention:  &duration111Seconds,
+						Delay:      &duration111Seconds,
+						Timeout:    &duration111Seconds,
+						DeadLetter: DeadLetterQueue{Tries: aws.Uint16(10)},
+						FIFO: FIFOAdvanceConfigOrBool{
+							Advanced: FIFOAdvanceConfig{
+								HighThroughputFifo:  aws.Bool(true),
+								FIFOThroughputLimit: aws.String(sqsFIFOThroughputLimitPerMessageGroupID),
+							},
+						},
+					},
+				},
+			},
+			wanted: errors.New(`validate "queue": must specify one, not both, of "high_throughput" and "throughput_limit"`),
+		},
+		"should return error if invalid combination of deduplication_scope and throughput_limit is defined": {
+			in: TopicSubscription{
+				Name:    aws.String("mockTopic"),
+				Service: aws.String("mockservice"),
+				Queue: SQSQueueOrBool{
+					Advanced: SQSQueue{
+						Retention:  &duration111Seconds,
+						Delay:      &duration111Seconds,
+						Timeout:    &duration111Seconds,
+						DeadLetter: DeadLetterQueue{Tries: aws.Uint16(10)},
+						FIFO: FIFOAdvanceConfigOrBool{
+							Advanced: FIFOAdvanceConfig{
+								FIFOThroughputLimit: aws.String(sqsFIFOThroughputLimitPerMessageGroupID),
+								DeduplicationScope:  aws.String(sqsDeduplicationScopeQueue),
+							},
+						},
+					},
+				},
+			},
+			wanted: errors.New(`validate "queue": "throughput_limit" must be set to "perQueue" when "deduplication_scope" is set to "queue"`),
+		},
+		"should not return error if valid standard queue config defined": {
+			in: TopicSubscription{
+				Name:    aws.String("mockTopic"),
+				Service: aws.String("mockservice"),
+				Queue: SQSQueueOrBool{
+					Advanced: SQSQueue{
+						Retention:  &duration111Seconds,
+						Delay:      &duration111Seconds,
+						Timeout:    &duration111Seconds,
+						DeadLetter: DeadLetterQueue{Tries: aws.Uint16(10)},
+					},
+				},
+			},
+			wanted: nil,
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
