@@ -210,7 +210,8 @@ type LogConfigOpts struct {
 
 // HTTPTargetContainer represents the target group of a load balancer that points to a container.
 type HTTPTargetContainer struct {
-	Port string // Port of the container.
+	Container string
+	Port      string // Port of the container.
 }
 
 // IsHTTPS returns true if the target container's port is 443.
@@ -234,6 +235,12 @@ type HTTPHealthCheckOpts struct {
 	DeregistrationDelay *int64
 }
 
+// IsHTTPS returns true if the Health Check Port is configured
+// as a HTTPS port.
+func (h HTTPHealthCheckOpts) IsHTTPS() bool {
+	return h.Port == "443"
+}
+
 // A Secret represents an SSM or SecretsManager secret that can be rendered in CloudFormation.
 type Secret interface {
 	RequiresSub() bool
@@ -322,6 +329,12 @@ type NetworkLoadBalancer struct {
 	MainContainerPort string
 }
 
+// ServiceConnect holds configuration for ECS Service Connect.
+type ServiceConnect struct {
+	Namespace string
+	Alias     *string
+}
+
 // AdvancedCount holds configuration for autoscaling and capacity provider
 // parameters.
 type AdvancedCount struct {
@@ -562,6 +575,7 @@ type WorkloadOpts struct {
 	AllowedSourceIps        []string
 	NLB                     *NetworkLoadBalancer
 	DeploymentConfiguration DeploymentConfigurationOpts
+	ServiceConnect          *ServiceConnect
 
 	// Custom Resources backed by Lambda functions.
 	CustomResources map[string]S3ObjectLocation
@@ -585,6 +599,24 @@ type WorkloadOpts struct {
 	Subscribe *SubscribeOpts
 }
 
+// HealthCheckProtocol returns the protocol for the Load Balancer health check,
+// or an empty string if it shouldn't be configured, defaulting to the
+// target protocol. (which is what happens, even if it isn't documented as such :))
+// https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticloadbalancingv2-targetgroup.html#cfn-elasticloadbalancingv2-targetgroup-healthcheckprotocol
+func (w WorkloadOpts) HealthCheckProtocol() string {
+	switch {
+	case w.HTTPHealthCheck.Port == "443":
+		return "HTTPS"
+	case w.HTTPTargetContainer.IsHTTPS() && w.HTTPHealthCheck.Port == "":
+		return "HTTPS"
+	case w.HTTPTargetContainer.IsHTTPS() && w.HTTPHealthCheck.Port != "443":
+		// for backwards compatability, only set HTTP if target
+		// container is https but the specified health check port is not
+		return "HTTP"
+	}
+	return ""
+}
+
 // ParseLoadBalancedWebService parses a load balanced web service's CloudFormation template
 // with the specified data object and returns its content.
 func (t *Template) ParseLoadBalancedWebService(data WorkloadOpts) (*Content, error) {
